@@ -1,5 +1,5 @@
 #! /bin/sh
-# Copyright (C) 2003-2012 Free Software Foundation, Inc.
+# Copyright (C) 2003-2024 Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 # Check that the DejaGnu rules do look for a testsuite named after
 # the package by default.
@@ -29,17 +29,25 @@ END
 chmod +x $package
 
 cat >> configure.ac << 'END'
+AC_CONFIG_FILES([testsuite/Makefile])
 AC_OUTPUT
 END
 
 cat > Makefile.am << END
-AUTOMAKE_OPTIONS = dejagnu
-EXTRA_DIST = $package $package.test/$package.exp
-AM_RUNTESTFLAGS = PACKAGE=\$(srcdir)/$package
+SUBDIRS = testsuite
+EXTRA_DIST = $package
 END
 
-mkdir $package.test
-cat > $package.test/$package.exp << 'END'
+mkdir testsuite
+
+cat > testsuite/Makefile.am << END
+AUTOMAKE_OPTIONS = dejagnu
+EXTRA_DIST = $package.test/$package.exp
+AM_RUNTESTFLAGS = PACKAGE=\$(top_srcdir)/$package
+END
+
+mkdir testsuite/$package.test
+cat > testsuite/$package.test/$package.exp << 'END'
 set test "a_dejagnu_test"
 spawn $PACKAGE
 expect {
@@ -55,8 +63,8 @@ $AUTOMAKE --add-missing
 ./configure
 
 $MAKE check
-test -f $package.log
-test -f $package.sum
+test -f testsuite/$package.log
+test -f testsuite/$package.sum
 
 $MAKE distcheck
 
