@@ -1,5 +1,5 @@
 #! /bin/sh
-# Copyright (C) 2002-2012 Free Software Foundation, Inc.
+# Copyright (C) 2002-2024 Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 # Test for += and backslashes.
 # Reported by Ralf Corsepius.
@@ -38,9 +38,8 @@ foo += b0.h \
   b1.h
 endif
 
-.PHONY: print
-print:
-	@echo BEG: $(foo) :END
+test:
+	is $(foo) == 0.h a0.h a1.h a2.h a3.h
 END
 
 $ACLOCAL
@@ -48,8 +47,6 @@ $AUTOCONF
 $AUTOMAKE
 
 ./configure
-$MAKE print >stdout || { cat stdout; exit 1; }
-cat stdout
-$FGREP 'BEG: 0.h a0.h a1.h a2.h a3.h :END' stdout
+$MAKE test
 
 :
